Replies to the questions a driver asks a terminal at startup, other than the graphics and keyboard ones.
cell_size_query/0 asks for the size of one cell in pixels; the reply
CSI 6 ; height ; width t parses to {:cell_size, {width, height}}.
Summary
Functions
The sequence that asks the terminal how many pixels one cell is.
Parse a report at the head of buffer, or :no_match.
Functions
@spec cell_size_query() :: String.t()
The sequence that asks the terminal how many pixels one cell is.
@spec parse(binary()) :: {[{:cell_size, {pos_integer(), pos_integer()}}], binary()} | :no_match
Parse a report at the head of buffer, or :no_match.